Method: Yt::Models::PlaylistItem#published_at

Defined in:
lib/yt/models/playlist_item.rb

#published_atTime (readonly)

Returns the time that the item was added to the playlist.

Returns:

  • (Time)

    the time that the item was added to the playlist.



30
# File 'lib/yt/models/playlist_item.rb', line 30

delegate :published_at, to: :snippet