Class: Yt::Collections::Subscribers
- Inherits:
-
SubscribedChannels
- Object
- Base
- Resources
- Channels
- SubscribedChannels
- Yt::Collections::Subscribers
- Defined in:
- lib/yt/collections/subscribers.rb
Overview
Provides methods to interact with subscribers of a YouTube resource.
Resources with subscribers are: accounts.
Confusingly, YouTube API provides the same endpoint to either
retrieve the channels that you are subscribed to or the channels
that are subscribed to you. The difference relies in the setting the
mySubscribers parameter to true and in reading the information
from the subscriberSnippet part, not the snippet part.
Method Summary
Methods inherited from Base
#includes, #initialize, of, #where
Constructor Details
This class inherits a constructor from Yt::Collections::Base