Method: Yt::Models::Account#owner_name

Defined in:
lib/yt/models/account.rb

#owner_nameString? (readonly)

The name of the content owner managing the account.

Returns:

  • (String)

    name of the CMS account, if the account is partnered.

  • (nil)

    if the account is not a partnered content owner.



135
136
137
# File 'lib/yt/models/account.rb', line 135

def owner_name
  @owner_name
end