Class: Yt::Models::LiveCuepoint

Inherits:
Base
  • Object
show all
Defined in:
lib/yt/models/live_cuepoint.rb

Overview

Provides methods to interact with YouTube Content ID live cuepoints.

Instance Method Summary collapse

Constructor Details

#initialize(options = {}) ⇒ LiveCuepoint

Returns a new instance of LiveCuepoint.



8
9
10
11
12
# File 'lib/yt/models/live_cuepoint.rb', line 8

def initialize(options = {})
  @data = options[:data]
  @id = options[:id]
  @auth = options[:auth]
end

Instance Method Details

#broadcast_idString

Returns the ID that uniquely identifies the broadcast that the live_cuepoint is associated with.

Returns:

  • (String)

    the ID that uniquely identifies the broadcast that the live_cuepoint is associated with.



20
# File 'lib/yt/models/live_cuepoint.rb', line 20

has_attribute :broadcast_id

#idString

Returns the ID that YouTube assigns and uses to uniquely identify the live_cuepoint.

Returns:

  • (String)

    the ID that YouTube assigns and uses to uniquely identify the live_cuepoint.



16
# File 'lib/yt/models/live_cuepoint.rb', line 16

has_attribute :id