Method: Yt::Models::Channel#comments
- Defined in:
- lib/yt/models/channel.rb
#comments(options = {}) ⇒ Hash<Date, Integer>, ...
Returns the comments grouped by the given dimension.
Examples:
Get the comments for each day of last week:
Get the comments for each day of last week:
resource.comments since: 2.weeks.ago, until: 1.week.ago, by: :day
# => {Wed, 8 May 2014 => 12.0, Thu, 9 May 2014 => 34.0, …}
Get the comments for this and last month:
Get the comments for this and last month:
resource.comments since: 1.month.ago, by: :month
# => {Wed, 01 Apr 2014..Thu, 30 Apr 2014 => 12.0, Fri, 01 May 2014..Sun, 31 May 2014 => 34.0, …}
Get the comments for the whole last week:
Get the comments for the whole last week:
resource.comments since: 2.weeks.ago, until: 1.week.ago, by: :range
# => {total: 564.0}
Get the comments for the whole last week in France only:
Get the comments for the whole last week in France only:
resource.comments since: 2.weeks.ago, until: 1.week.ago, by: :range, in: 'FR'
# => {total: 44.0}
Parameters:
-
options
(Hash)
(defaults to: {})
—
the time-range and dimensions for the comments.
Options Hash (options):
-
:by
(Symbol)
— default:
:day
—
The dimension to collect comments by. Accepted values are:
:day,:month, :range. -
:since
(#to_date)
—
The first day of the time-range. Also aliased as
:from. -
:until
(#to_date)
—
The last day of the time-range. Also aliased as
:to. -
:in
(<String, Hash>)
—
The country to limit the comments to. Can either be the two-letter ISO-3166-1 code of a country, such as “US”, or a Hash with the code in the
:countrykey, such as {country: “US”}.
Returns:
-
(Hash<Date, Integer>)
—
if grouped by day, the comments for each day in the time-range.
-
(Hash<Range<Date, Date>, Integer>)
—
if grouped by month, the comments for each month in the time-range.
-
(Hash<Symbol, Integer>)
—
if grouped by range, the comments for the entire time-range (under the key
:total).
150 |
# File 'lib/yt/models/channel.rb', line 150 has_report :comments, Integer |