Class: Yt::Models::LiveCuepoint
- Inherits:
-
Base
- Object
- Base
- Yt::Models::LiveCuepoint
- Defined in:
- lib/yt/models/live_cuepoint.rb
Overview
Provides methods to interact with YouTube Content ID live cuepoints.
Instance Method Summary collapse
-
#broadcast_id ⇒ String
The ID that uniquely identifies the broadcast that the live_cuepoint is associated with.
-
#id ⇒ String
The ID that YouTube assigns and uses to uniquely identify the live_cuepoint.
-
#initialize(options = {}) ⇒ LiveCuepoint
constructor
A new instance of LiveCuepoint.
Constructor Details
#initialize(options = {}) ⇒ LiveCuepoint
Returns a new instance of LiveCuepoint.
8 9 10 11 12 |
# File 'lib/yt/models/live_cuepoint.rb', line 8 def initialize( = {}) @data = [:data] @id = [:id] @auth = [:auth] end |
Instance Method Details
#broadcast_id ⇒ String
Returns the ID that uniquely identifies the broadcast that the live_cuepoint is associated with.
20 |
# File 'lib/yt/models/live_cuepoint.rb', line 20 has_attribute :broadcast_id |
#id ⇒ String
Returns the ID that YouTube assigns and uses to uniquely identify the live_cuepoint.
16 |
# File 'lib/yt/models/live_cuepoint.rb', line 16 has_attribute :id |